@@ -37,6 +37,8 @@ import wsme
 from wsme import types as wtypes
 import wsmeext.pecan as wsme_pecan
 
+from oslo_log import log
+
 from watcher._i18n import _
 from watcher.api.controllers import base
 from watcher.api.controllers import link
@@ -49,9 +51,13 @@ from watcher.common import utils
 from watcher.decision_engine import rpcapi
 from watcher import objects
 
+LOG = log.getLogger(__name__)
+
 
 class AuditPostType(wtypes.Base):
 
+    name = wtypes.wsattr(wtypes.text, mandatory=False)
+
     audit_template_uuid = wtypes.wsattr(types.uuid, mandatory=False)
 
     goal = wtypes.wsattr(wtypes.text, mandatory=False)
@@ -65,7 +71,7 @@ class AuditPostType(wtypes.Base):
 
     parameters = wtypes.wsattr({wtypes.text: types.jsontype}, mandatory=False,
                                default={})
-    interval = wsme.wsattr(int, mandatory=False)
+    interval = wsme.wsattr(types.interval_or_cron, mandatory=False)
 
     scope = wtypes.wsattr(types.jsontype, readonly=True)
 
@@ -111,7 +117,30 @@ class AuditPostType(wtypes.Base):
                         setattr(self, k, at_attr)
                     except AttributeError:
                         pass
+
+        # Note: If audit name was not provided, used a default name
+        if not self.name:
+            if self.strategy:
+                strategy = objects.Strategy.get(context, self.strategy)
+                self.name = "%s-%s" % (strategy.name,
+                                       datetime.datetime.utcnow().isoformat())
+            elif self.audit_template_uuid:
+                audit_template = objects.AuditTemplate.get(
+                    context, self.audit_template_uuid)
+                self.name = "%s-%s" % (audit_template.name,
+                                       datetime.datetime.utcnow().isoformat())
+            else:
+                goal = objects.Goal.get(context, self.goal)
+                self.name = "%s-%s" % (goal.name,
+                                       datetime.datetime.utcnow().isoformat())
+        # No more than 63 characters
+        if len(self.name) > 63:
+            LOG.warning("Audit: %s length exceeds 63 characters",
+                        self.name)
+            self.name = self.name[0:63]
+
         return Audit(
+            name=self.name,
             audit_type=self.audit_type,
             parameters=self.parameters,
             goal_id=self.goal,
@@ -146,10 +175,10 @@ class AuditPatchType(types.JsonPatchType):
 
 
 class Audit(base.APIBase):
-    """API representation of a audit.
+    """API representation of an audit.
 
     This class enforces type checking and value constraints, and converts
-    between the internal object model and the API representation of a audit.
+    between the internal object model and the API representation of an audit.
     """
     _goal_uuid = None
     _goal_name = None
@@ -233,6 +262,9 @@ class Audit(base.APIBase):
     uuid = types.uuid
     """Unique UUID for this audit"""
 
+    name = wtypes.text
+    """Name of this audit"""
+
     audit_type = wtypes.text
     """Type of this audit"""
 
@@ -241,19 +273,19 @@ class Audit(base.APIBase):
 
     goal_uuid = wsme.wsproperty(
         wtypes.text, _get_goal_uuid, _set_goal_uuid, mandatory=True)
-    """Goal UUID the audit template refers to"""
+    """Goal UUID the audit refers to"""
 
     goal_name = wsme.wsproperty(
         wtypes.text, _get_goal_name, _set_goal_name, mandatory=False)
-    """The name of the goal this audit template refers to"""
+    """The name of the goal this audit refers to"""
 
     strategy_uuid = wsme.wsproperty(
         wtypes.text, _get_strategy_uuid, _set_strategy_uuid, mandatory=False)
-    """Strategy UUID the audit template refers to"""
+    """Strategy UUID the audit refers to"""
 
     strategy_name = wsme.wsproperty(
         wtypes.text, _get_strategy_name, _set_strategy_name, mandatory=False)
-    """The name of the strategy this audit template refers to"""
+    """The name of the strategy this audit refers to"""
 
     parameters = {wtypes.text: types.jsontype}
     """The strategy parameters for this audit"""
@@ -261,7 +293,7 @@ class Audit(base.APIBase):
     links = wsme.wsattr([link.Link], readonly=True)
     """A list containing a self link and associated audit links"""
 
-    interval = wsme.wsattr(int, mandatory=False)
+    interval = wsme.wsattr(wtypes.text, mandatory=False)
     """Launch audit periodically (in seconds)"""
 
     scope = wsme.wsattr(types.jsontype, mandatory=False)
@@ -270,6 +302,9 @@ class Audit(base.APIBase):
     auto_trigger = wsme.wsattr(bool, mandatory=False, default=False)
     """Autoexecute action plan once audit is succeeded"""
 
+    next_run_time = wsme.wsattr(datetime.datetime, mandatory=False)
+    """The next time audit launch"""
+
     def __init__(self, **kwargs):
         self.fields = []
         fields = list(objects.Audit.fields)
@@ -298,10 +333,11 @@ class Audit(base.APIBase):
     @staticmethod
     def _convert_with_links(audit, url, expand=True):
         if not expand:
-            audit.unset_fields_except(['uuid', 'audit_type', 'state',
+            audit.unset_fields_except(['uuid', 'name', 'audit_type', 'state',
                                        'goal_uuid', 'interval', 'scope',
                                        'strategy_uuid', 'goal_name',
-                                       'strategy_name', 'auto_trigger'])
+                                       'strategy_name', 'auto_trigger',
+                                       'next_run_time'])
 
         audit.links = [link.Link.make_link('self', url,
                                            'audits', audit.uuid),
@@ -320,14 +356,16 @@ class Audit(base.APIBase):
     @classmethod
     def sample(cls, expand=True):
         sample = cls(uuid='27e3153e-d5bf-4b7e-b517-fb518e17f34c',
+                     name='My Audit',
                      audit_type='ONESHOT',
                      state='PENDING',
                      created_at=datetime.datetime.utcnow(),
                      deleted_at=None,
                      updated_at=datetime.datetime.utcnow(),
-                     interval=7200,
+                     interval='7200',
                      scope=[],
-                     auto_trigger=False)
+                     auto_trigger=False,
+                     next_run_time=datetime.datetime.utcnow())
 
         sample.goal_id = '7ae81bb3-dec3-4289-8d6c-da80bd8001ae'
         sample.strategy_id = '7ae81bb3-dec3-4289-8d6c-da80bd8001ff'
@@ -478,17 +516,17 @@ class AuditsController(rest.RestController):
                                            resource_url,
                                            goal=goal)
 
-    @wsme_pecan.wsexpose(Audit, types.uuid)
-    def get_one(self, audit_uuid):
+    @wsme_pecan.wsexpose(Audit, wtypes.text)
+    def get_one(self, audit):
         """Retrieve information about the given audit.
 
-        :param audit_uuid: UUID of a audit.
+        :param audit: UUID or name of an audit.
         """
         if self.from_audits:
             raise exception.OperationNotPermitted
 
         context = pecan.request.context
-        rpc_audit = api_utils.get_resource('Audit', audit_uuid)
+        rpc_audit = api_utils.get_resource('Audit', audit)
         policy.enforce(context, 'audit:get', rpc_audit, action='audit:get')
 
         return Audit.convert_with_links(rpc_audit)
@@ -497,7 +535,7 @@ class AuditsController(rest.RestController):
     def post(self, audit_p):
         """Create a new audit.
 
-        :param audit_p: a audit within the request body.
+        :param audit_p: an audit within the request body.
         """
         context = pecan.request.context
         policy.enforce(context, 'audit:create',
@@ -527,7 +565,7 @@ class AuditsController(rest.RestController):
 
         if no_schema and audit.parameters:
             raise exception.Invalid(_('Specify parameters but no predefined '
-                                      'strategy for audit template, or no '
+                                      'strategy for audit, or no '
                                       'parameter spec in predefined strategy'))
 
         audit_dict = audit.as_dict()
@@ -546,11 +584,11 @@ class AuditsController(rest.RestController):
         return Audit.convert_with_links(new_audit)
 
     @wsme.validate(types.uuid, [AuditPatchType])
-    @wsme_pecan.wsexpose(Audit, types.uuid, body=[AuditPatchType])
-    def patch(self, audit_uuid, patch):
+    @wsme_pecan.wsexpose(Audit, wtypes.text, body=[AuditPatchType])
+    def patch(self, audit, patch):
         """Update an existing audit.
 
-        :param audit_uuid: UUID of a audit.
+        :param audit: UUID or name of an audit.
         :param patch: a json PATCH document to apply to this audit.
         """
         if self.from_audits:
@@ -558,7 +596,7 @@ class AuditsController(rest.RestController):
 
         context = pecan.request.context
         audit_to_update = api_utils.get_resource(
-            'Audit', audit_uuid, eager=True)
+            'Audit', audit, eager=True)
         policy.enforce(context, 'audit:update', audit_to_update,
                        action='audit:update')
 
@@ -595,16 +633,23 @@ class AuditsController(rest.RestController):
         audit_to_update.save()
         return Audit.convert_with_links(audit_to_update)
 
-    @wsme_pecan.wsexpose(None, types.uuid, status_code=204)
-    def delete(self, audit_uuid):
-        """Delete a audit.
+    @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
+    def delete(self, audit):
+        """Delete an audit.
 
-        :param audit_uuid: UUID of a audit.
+        :param audit: UUID or name of an audit.
         """
         context = pecan.request.context
         audit_to_delete = api_utils.get_resource(
-            'Audit', audit_uuid, eager=True)
+            'Audit', audit, eager=True)
         policy.enforce(context, 'audit:update', audit_to_delete,
                        action='audit:update')
 
+        initial_state = audit_to_delete.state
+        new_state = objects.audit.State.DELETED
+        if not objects.audit.AuditStateTransitionManager(
+                ).check_transition(initial_state, new_state):
+            raise exception.DeleteError(
+                state=initial_state)
+
         audit_to_delete.soft_delete()
