@@ -52,14 +52,21 @@ class NovaHelper(object):
         return self.nova.hypervisors.get(utils.Struct(id=node_id))
 
     def get_compute_node_by_hostname(self, node_hostname):
-        """Get compute node by ID (*not* UUID)"""
-        # We need to pass an object with an 'id' attribute to make it work
+        """Get compute node by hostname"""
         try:
-            compute_nodes = self.nova.hypervisors.search(node_hostname)
-            if len(compute_nodes) != 1:
+            hypervisors = [hv for hv in self.get_compute_node_list()
+                           if hv.service['host'] == node_hostname]
+            if len(hypervisors) != 1:
+                # TODO(hidekazu)
+                # this may occur if VMware vCenter driver is used
                 raise exception.ComputeNodeNotFound(name=node_hostname)
+            else:
+                compute_nodes = self.nova.hypervisors.search(
+                    hypervisors[0].hypervisor_hostname)
+                if len(compute_nodes) != 1:
+                    raise exception.ComputeNodeNotFound(name=node_hostname)
 
-            return self.get_compute_node_by_id(compute_nodes[0].id)
+                return self.get_compute_node_by_id(compute_nodes[0].id)
         except Exception as exc:
             LOG.exception(exc)
             raise exception.ComputeNodeNotFound(name=node_hostname)
@@ -67,12 +74,12 @@ class NovaHelper(object):
     def get_instance_list(self):
         return self.nova.servers.list(search_opts={'all_tenants': True})
 
+    def get_flavor_list(self):
+        return self.nova.flavors.list(**{'is_public': None})
+
     def get_service(self, service_id):
         return self.nova.services.find(id=service_id)
 
-    def get_flavor(self, flavor_id):
-        return self.nova.flavors.get(flavor_id)
-
     def get_aggregate_list(self):
         return self.nova.aggregates.list()
 
@@ -203,11 +210,7 @@ class NovaHelper(object):
                 new_image_name = getattr(image, "name")
 
             instance_name = getattr(instance, "name")
-            flavordict = getattr(instance, "flavor")
-            # a_dict = dict([flavorstr.strip('{}').split(":"),])
-            flavor_id = flavordict["id"]
-            flavor = self.nova.flavors.get(flavor_id)
-            flavor_name = getattr(flavor, "name")
+            flavor_name = instance.flavor.get('original_name')
             keypair_name = getattr(instance, "key_name")
 
             addresses = getattr(instance, "addresses")
@@ -425,8 +428,7 @@ class NovaHelper(object):
 
         return True
 
-    def live_migrate_instance(self, instance_id, dest_hostname,
-                              block_migration=False, retry=120):
+    def live_migrate_instance(self, instance_id, dest_hostname, retry=120):
         """This method does a live migration of a given instance
 
         This method uses the Nova built-in live_migrate()
@@ -439,7 +441,6 @@ class NovaHelper(object):
         :param dest_hostname: the name of the destination compute node, if
                               destination_node is None, nova scheduler choose
                               the destination host
-        :param block_migration:  No shared storage is required.
         """
         LOG.debug("Trying to live migrate instance %s " % (instance_id))
 
@@ -453,9 +454,9 @@ class NovaHelper(object):
             LOG.debug(
                 "Instance %s found on host '%s'." % (instance_id, host_name))
 
-            instance.live_migrate(host=dest_hostname,
-                                  block_migration=block_migration,
-                                  disk_over_commit=True)
+            # From nova api version 2.25(Mitaka release), the default value of
+            # block_migration is None which is mapped to 'auto'.
+            instance.live_migrate(host=dest_hostname)
 
             instance = self.nova.servers.get(instance_id)
 
@@ -483,6 +484,9 @@ class NovaHelper(object):
                           'OS-EXT-SRV-ATTR:host') != dest_hostname \
                     and retry:
                 instance = self.nova.servers.get(instance.id)
+                if not getattr(instance, 'OS-EXT-STS:task_state'):
+                    LOG.debug("Instance task state: %s is null" % instance_id)
+                    break
                 LOG.debug(
                     'Waiting the migration of {0}  to {1}'.format(
                         instance,
@@ -528,10 +532,10 @@ class NovaHelper(object):
         instance_host = getattr(instance, 'OS-EXT-SRV-ATTR:host')
         instance_status = getattr(instance, 'status')
 
-        # Abort live migration successfull, action is cancelled
+        # Abort live migration successful, action is cancelled
         if instance_host == source and instance_status == 'ACTIVE':
             return True
-        # Nova Unable to abort live migration, action is succeded
+        # Nova Unable to abort live migration, action is succeeded
         elif instance_host == destination and instance_status == 'ACTIVE':
             return False
 
@@ -547,16 +551,17 @@ class NovaHelper(object):
         else:
             return False
 
-    def disable_service_nova_compute(self, hostname):
-        if self.nova.services.disable(host=hostname,
-                                      binary='nova-compute'). \
+    def disable_service_nova_compute(self, hostname, reason=None):
+        if self.nova.services.disable_log_reason(host=hostname,
+                                                 binary='nova-compute',
+                                                 reason=reason). \
                 status == 'disabled':
             return True
         else:
             return False
 
     def set_host_offline(self, hostname):
-        # See API on http://developer.openstack.org/api-ref-compute-v2.1.html
+        # See API on https://developer.openstack.org/api-ref/compute/
         # especially the PUT request
         # regarding this resource : /v2.1/os-hosts/​{host_name}​
         #
@@ -772,10 +777,9 @@ class NovaHelper(object):
 
         # Make sure all security groups exist
         for sec_group_name in sec_group_list:
-            try:
-                self.nova.security_groups.find(name=sec_group_name)
+            group_id = self.get_security_group_id_from_name(sec_group_name)
 
-            except nvexceptions.NotFound:
+            if not group_id:
                 LOG.debug("Security group '%s' not found " % sec_group_name)
                 return
 
@@ -822,6 +826,14 @@ class NovaHelper(object):
 
         return instance
 
+    def get_security_group_id_from_name(self, group_name="default"):
+        """This method returns the security group of the provided group name"""
+        security_groups = self.neutron.list_security_groups(name=group_name)
+
+        security_group_id = security_groups['security_groups'][0]['id']
+
+        return security_group_id
+
     def get_network_id_from_name(self, net_name="private"):
         """This method returns the unique id of the provided network name"""
         networks = self.neutron.list_networks(name=net_name)
