@@ -649,8 +649,7 @@ class Connection(api.BaseConnection):
             query = self._set_eager_options(models.Audit, query)
         query = self._add_audits_filters(query, filters)
         if not context.show_deleted:
-            query = query.filter(
-                ~(models.Audit.state == objects.audit.State.DELETED))
+            query = query.filter_by(deleted_at=None)
 
         return _paginate_query(models.Audit, limit, marker,
                                sort_key, sort_dir, query)
@@ -660,6 +659,14 @@ class Connection(api.BaseConnection):
         if not values.get('uuid'):
             values['uuid'] = utils.generate_uuid()
 
+        query = model_query(models.Audit)
+        query = query.filter_by(name=values.get('name'),
+                                deleted_at=None)
+
+        if len(query.all()) > 0:
+            raise exception.AuditAlreadyExists(
+                audit=values['name'])
+
         if values.get('state') is None:
             values['state'] = objects.audit.State.PENDING
 
@@ -669,7 +676,7 @@ class Connection(api.BaseConnection):
         try:
             audit = self._create(models.Audit, values)
         except db_exc.DBDuplicateEntry:
-            raise exception.AuditAlreadyExists(uuid=values['uuid'])
+            raise exception.AuditAlreadyExists(audit=values['uuid'])
         return audit
 
     def _get_audit(self, context, fieldname, value, eager):
@@ -687,6 +694,10 @@ class Connection(api.BaseConnection):
         return self._get_audit(
             context, fieldname="uuid", value=audit_uuid, eager=eager)
 
+    def get_audit_by_name(self, context, audit_name, eager=False):
+        return self._get_audit(
+            context, fieldname="name", value=audit_name, eager=eager)
+
     def destroy_audit(self, audit_id):
         def is_audit_referenced(session, audit_id):
             """Checks whether the audit is referenced by action_plan(s)."""
@@ -736,8 +747,7 @@ class Connection(api.BaseConnection):
             query = self._set_eager_options(models.Action, query)
         query = self._add_actions_filters(query, filters)
         if not context.show_deleted:
-            query = query.filter(
-                ~(models.Action.state == objects.action.State.DELETED))
+            query = query.filter_by(deleted_at=None)
         return _paginate_query(models.Action, limit, marker,
                                sort_key, sort_dir, query)
 
@@ -817,9 +827,7 @@ class Connection(api.BaseConnection):
             query = self._set_eager_options(models.ActionPlan, query)
         query = self._add_action_plans_filters(query, filters)
         if not context.show_deleted:
-            query = query.filter(
-                ~(models.ActionPlan.state ==
-                  objects.action_plan.State.DELETED))
+            query = query.filter(models.ActionPlan.deleted_at.is_(None))
 
         return _paginate_query(models.ActionPlan, limit, marker,
                                sort_key, sort_dir, query)
@@ -1131,3 +1139,74 @@ class Connection(api.BaseConnection):
             return self._soft_delete(models.Service, service_id)
         except exception.ResourceNotFound:
             raise exception.ServiceNotFound(service=service_id)
+
+    # ### ACTION_DESCRIPTIONS ### #
+
+    def _add_action_descriptions_filters(self, query, filters):
+        if not filters:
+            filters = {}
+
+        plain_fields = ['id', 'action_type']
+
+        return self._add_filters(
+            query=query, model=models.ActionDescription, filters=filters,
+            plain_fields=plain_fields)
+
+    def get_action_description_list(self, context, filters=None, limit=None,
+                                    marker=None, sort_key=None,
+                                    sort_dir=None, eager=False):
+        query = model_query(models.ActionDescription)
+        if eager:
+            query = self._set_eager_options(models.ActionDescription, query)
+        query = self._add_action_descriptions_filters(query, filters)
+        if not context.show_deleted:
+            query = query.filter_by(deleted_at=None)
+        return _paginate_query(models.ActionDescription, limit, marker,
+                               sort_key, sort_dir, query)
+
+    def create_action_description(self, values):
+        try:
+            action_description = self._create(models.ActionDescription, values)
+        except db_exc.DBDuplicateEntry:
+            raise exception.ActionDescriptionAlreadyExists(
+                action_type=values['action_type'])
+        return action_description
+
+    def _get_action_description(self, context, fieldname, value, eager):
+        try:
+            return self._get(context, model=models.ActionDescription,
+                             fieldname=fieldname, value=value, eager=eager)
+        except exception.ResourceNotFound:
+            raise exception.ActionDescriptionNotFound(action_id=value)
+
+    def get_action_description_by_id(self, context,
+                                     action_id, eager=False):
+                return self._get_action_description(
+                    context, fieldname="id", value=action_id, eager=eager)
+
+    def get_action_description_by_type(self, context,
+                                       action_type, eager=False):
+        return self._get_action_description(
+            context, fieldname="action_type", value=action_type, eager=eager)
+
+    def destroy_action_description(self, action_id):
+        try:
+            return self._destroy(models.ActionDescription, action_id)
+        except exception.ResourceNotFound:
+            raise exception.ActionDescriptionNotFound(
+                action_id=action_id)
+
+    def update_action_description(self, action_id, values):
+        try:
+            return self._update(models.ActionDescription,
+                                action_id, values)
+        except exception.ResourceNotFound:
+            raise exception.ActionDescriptionNotFound(
+                action_id=action_id)
+
+    def soft_delete_action_description(self, action_id):
+        try:
+            return self._soft_delete(models.ActionDescription, action_id)
+        except exception.ResourceNotFound:
+            raise exception.ActionDescriptionNotFound(
+                action_id=action_id)
