@@ -21,6 +21,7 @@ from watcher.decision_engine.model.collector import base
 from watcher.decision_engine.model import element
 from watcher.decision_engine.model import model_root
 from watcher.decision_engine.model.notification import nova
+from watcher.decision_engine.scope import compute as compute_scope
 
 LOG = log.getLogger(__name__)
 
@@ -32,6 +33,109 @@ class NovaClusterDataModelCollector(base.BaseClusterDataModelCollector):
     representation of the resources exposed by the compute service.
     """
 
+    HOST_AGGREGATES = "#/items/properties/compute/host_aggregates/"
+    SCHEMA = {
+        "$schema": "http://json-schema.org/draft-04/schema#",
+        "type": "array",
+        "items": {
+            "type": "object",
+            "properties": {
+                "host_aggregates": {
+                    "type": "array",
+                    "items": {
+                        "anyOf": [
+                            {"$ref": HOST_AGGREGATES + "id"},
+                            {"$ref": HOST_AGGREGATES + "name"},
+                        ]
+                    }
+                },
+                "availability_zones": {
+                    "type": "array",
+                    "items": {
+                        "type": "object",
+                        "properties": {
+                            "name": {
+                                "type": "string"
+                            }
+                        },
+                        "additionalProperties": False
+                    }
+                },
+                "exclude": {
+                    "type": "array",
+                    "items": {
+                        "type": "object",
+                        "properties": {
+                            "instances": {
+                                "type": "array",
+                                "items": {
+                                    "type": "object",
+                                    "properties": {
+                                        "uuid": {
+                                            "type": "string"
+                                        }
+                                    },
+                                    "additionalProperties": False
+                                }
+                            },
+                            "compute_nodes": {
+                                "type": "array",
+                                "items": {
+                                    "type": "object",
+                                    "properties": {
+                                        "name": {
+                                            "type": "string"
+                                        }
+                                    },
+                                    "additionalProperties": False
+                                }
+                            },
+                            "host_aggregates": {
+                                "type": "array",
+                                "items": {
+                                    "anyOf": [
+                                        {"$ref": HOST_AGGREGATES + "id"},
+                                        {"$ref": HOST_AGGREGATES + "name"},
+                                    ]
+                                }
+                            },
+                            "instance_metadata": {
+                                "type": "array",
+                                "items": {
+                                    "type": "object"
+                                }
+                            }
+                        },
+                        "additionalProperties": False
+                    }
+                }
+            },
+            "additionalProperties": False
+        },
+        "host_aggregates": {
+            "id": {
+                "properties": {
+                    "id": {
+                        "oneOf": [
+                            {"type": "integer"},
+                            {"enum": ["*"]}
+                        ]
+                    }
+                },
+                "additionalProperties": False
+            },
+            "name": {
+                "properties": {
+                    "name": {
+                        "type": "string"
+                    }
+                },
+                "additionalProperties": False
+            }
+        },
+        "additionalProperties": False
+    }
+
     def __init__(self, config, osc=None):
         super(NovaClusterDataModelCollector, self).__init__(config, osc)
 
@@ -53,8 +157,15 @@ class NovaClusterDataModelCollector(base.BaseClusterDataModelCollector):
             nova.LegacyInstanceUpdated(self),
             nova.LegacyInstanceDeletedEnd(self),
             nova.LegacyLiveMigratedEnd(self),
+            nova.LegacyInstanceResizeConfirmEnd(self),
+            nova.LegacyInstanceRebuildEnd(self),
         ]
 
+    def get_audit_scope_handler(self, audit_scope):
+        self._audit_scope_handler = compute_scope.ComputeScope(
+            audit_scope, self.config)
+        return self._audit_scope_handler
+
     def execute(self):
         """Build the compute cluster data model"""
         LOG.debug("Building latest Nova cluster data model")
@@ -117,7 +228,7 @@ class ModelBuilder(object):
         # cpu_id, cpu_node = self.build_cpu_compute_node(base_id, node)
         # self.add_node(cpu_id, cpu_node)
 
-        # # Connect the base compute node to the dependant nodes.
+        # # Connect the base compute node to the dependent nodes.
         # self.add_edges_from([(base_id, disk_id), (base_id, mem_id),
         #                      (base_id, cpu_id), (base_id, net_id)],
         #                     label="contains")
@@ -139,7 +250,8 @@ class ModelBuilder(object):
             "disk_capacity": node.local_gb,
             "vcpus": node.vcpus,
             "state": node.state,
-            "status": node.status}
+            "status": node.status,
+            "disabled_reason": compute_service.disabled_reason}
 
         compute_node = element.ComputeNode(**node_attributes)
         # compute_node = self._build_node("physical", "compute", "hypervisor",
@@ -227,15 +339,16 @@ class ModelBuilder(object):
         :param instance: Nova VM object.
         :return: A instance node for the graph.
         """
-        flavor = self.nova_helper.get_flavor(instance.flavor["id"])
+        flavor = instance.flavor
         instance_attributes = {
             "uuid": instance.id,
             "human_id": instance.human_id,
-            "memory": flavor.ram,
-            "disk": flavor.disk,
-            "disk_capacity": flavor.disk,
-            "vcpus": flavor.vcpus,
-            "state": getattr(instance, "OS-EXT-STS:vm_state")}
+            "memory": flavor["ram"],
+            "disk": flavor["disk"],
+            "disk_capacity": flavor["disk"],
+            "vcpus": flavor["vcpus"],
+            "state": getattr(instance, "OS-EXT-STS:vm_state"),
+            "metadata": instance.metadata}
 
         # node_attributes = dict()
         # node_attributes["layer"] = "virtual"
