@@ -16,6 +16,7 @@
 
 import enum
 
+from watcher.decision_engine.model.element import baremetal_resource
 from watcher.decision_engine.model.element import compute_resource
 from watcher.decision_engine.model.element import storage_resource
 from watcher.objects import base
@@ -33,11 +34,11 @@ class ServiceState(enum.Enum):
 class ComputeNode(compute_resource.ComputeResource):
 
     fields = {
-        "id": wfields.NonNegativeIntegerField(),
+        "id": wfields.StringField(),
         "hostname": wfields.StringField(),
         "status": wfields.StringField(default=ServiceState.ENABLED.value),
+        "disabled_reason": wfields.StringField(nullable=True),
         "state": wfields.StringField(default=ServiceState.ONLINE.value),
-
         "memory": wfields.NonNegativeIntegerField(),
         "disk": wfields.IntegerField(),
         "disk_capacity": wfields.NonNegativeIntegerField(),
@@ -56,7 +57,7 @@ class StorageNode(storage_resource.StorageResource):
         "zone": wfields.StringField(),
         "status": wfields.StringField(default=ServiceState.ENABLED.value),
         "state": wfields.StringField(default=ServiceState.ONLINE.value),
-        "volume_type": wfields.StringField()
+        "volume_type": wfields.ListOfStringsField()
     }
 
     def accept(self, visitor):
@@ -78,3 +79,17 @@ class Pool(storage_resource.StorageResource):
 
     def accept(self, visitor):
         raise NotImplementedError()
+
+
+@base.WatcherObjectRegistry.register_if(False)
+class IronicNode(baremetal_resource.BaremetalResource):
+
+    fields = {
+        "power_state": wfields.StringField(),
+        "maintenance": wfields.BooleanField(),
+        "maintenance_reason": wfields.StringField(),
+        "extra": wfields.DictField()
+    }
+
+    def accept(self, visitor):
+        raise NotImplementedError()
