@@ -46,13 +46,76 @@ from watcher.common import context
 from watcher.common import exception
 from watcher.common.loader import loadable
 from watcher.common import utils
+from watcher.datasource import manager as ds_manager
 from watcher.decision_engine.loading import default as loading
 from watcher.decision_engine.model.collector import manager
-from watcher.decision_engine.scope import default as default_scope
 from watcher.decision_engine.solution import default
 from watcher.decision_engine.strategy.common import level
 
 
+class StrategyEndpoint(object):
+    def __init__(self, messaging):
+        self._messaging = messaging
+
+    def _collect_metrics(self, strategy, datasource):
+        metrics = []
+        if not datasource:
+            return {'type': 'Metrics', 'state': metrics,
+                    'mandatory': False, 'comment': ''}
+        else:
+            ds_metrics = datasource.list_metrics()
+            if ds_metrics is None:
+                raise exception.DataSourceNotAvailable(
+                    datasource=datasource.NAME)
+            else:
+                for metric in strategy.DATASOURCE_METRICS:
+                    original_metric_name = datasource.METRIC_MAP.get(metric)
+                    if original_metric_name in ds_metrics:
+                        metrics.append({original_metric_name: 'available'})
+                    else:
+                        metrics.append({original_metric_name: 'not available'})
+        return {'type': 'Metrics', 'state': metrics,
+                'mandatory': False, 'comment': ''}
+
+    def _get_datasource_status(self, strategy, datasource):
+        if not datasource:
+            state = "Datasource is not presented for this strategy"
+        else:
+            state = "%s: %s" % (datasource.NAME,
+                                datasource.check_availability())
+        return {'type': 'Datasource',
+                'state': state,
+                'mandatory': True, 'comment': ''}
+
+    def _get_cdm(self, strategy):
+        models = []
+        for model in ['compute_model', 'storage_model', 'baremetal_model']:
+            try:
+                getattr(strategy, model)
+            except Exception:
+                models.append({model: 'not available'})
+            else:
+                models.append({model: 'available'})
+        return {'type': 'CDM', 'state': models,
+                'mandatory': True, 'comment': ''}
+
+    def get_strategy_info(self, context, strategy_name):
+        strategy = loading.DefaultStrategyLoader().load(strategy_name)
+        try:
+            is_datasources = getattr(strategy.config, 'datasources', None)
+            if is_datasources:
+                datasource = getattr(strategy, 'datasource_backend')
+            else:
+                datasource = getattr(strategy, strategy.config.datasource)
+        except (AttributeError, IndexError):
+            datasource = []
+        available_datasource = self._get_datasource_status(strategy,
+                                                           datasource)
+        available_metrics = self._collect_metrics(strategy, datasource)
+        available_cdm = self._get_cdm(strategy)
+        return [available_datasource, available_metrics, available_cdm]
+
+
 @six.add_metaclass(abc.ABCMeta)
 class BaseStrategy(loadable.Loadable):
     """A base class for all the strategies
@@ -61,6 +124,8 @@ class BaseStrategy(loadable.Loadable):
     Solution for a given Goal.
     """
 
+    DATASOURCE_METRICS = []
+
     def __init__(self, config, osc=None):
         """Constructor: the signature should be identical within the subclasses
 
@@ -83,9 +148,10 @@ class BaseStrategy(loadable.Loadable):
         self._collector_manager = None
         self._compute_model = None
         self._storage_model = None
+        self._baremetal_model = None
         self._input_parameters = utils.Struct()
         self._audit_scope = None
-        self._audit_scope_handler = None
+        self._datasource_backend = None
 
     @classmethod
     @abc.abstractmethod
@@ -182,7 +248,9 @@ class BaseStrategy(loadable.Loadable):
         if self._compute_model is None:
             collector = self.collector_manager.get_cluster_model_collector(
                 'compute', osc=self.osc)
-            self._compute_model = self.audit_scope_handler.get_scoped_model(
+            audit_scope_handler = collector.get_audit_scope_handler(
+                audit_scope=self.audit_scope)
+            self._compute_model = audit_scope_handler.get_scoped_model(
                 collector.get_latest_cluster_data_model())
 
         if not self._compute_model:
@@ -203,7 +271,9 @@ class BaseStrategy(loadable.Loadable):
         if self._storage_model is None:
             collector = self.collector_manager.get_cluster_model_collector(
                 'storage', osc=self.osc)
-            self._storage_model = self.audit_scope_handler.get_scoped_model(
+            audit_scope_handler = collector.get_audit_scope_handler(
+                audit_scope=self.audit_scope)
+            self._storage_model = audit_scope_handler.get_scoped_model(
                 collector.get_latest_cluster_data_model())
 
         if not self._storage_model:
@@ -214,6 +284,29 @@ class BaseStrategy(loadable.Loadable):
 
         return self._storage_model
 
+    @property
+    def baremetal_model(self):
+        """Cluster data model
+
+        :returns: Cluster data model the strategy is executed on
+        :rtype model: :py:class:`~.ModelRoot` instance
+        """
+        if self._baremetal_model is None:
+            collector = self.collector_manager.get_cluster_model_collector(
+                'baremetal', osc=self.osc)
+            audit_scope_handler = collector.get_audit_scope_handler(
+                audit_scope=self.audit_scope)
+            self._baremetal_model = audit_scope_handler.get_scoped_model(
+                collector.get_latest_cluster_data_model())
+
+        if not self._baremetal_model:
+            raise exception.ClusterStateNotDefined()
+
+        if self._baremetal_model.stale:
+            raise exception.ClusterStateStale()
+
+        return self._baremetal_model
+
     @classmethod
     def get_schema(cls):
         """Defines a Schema that the input parameters shall comply to
@@ -223,6 +316,15 @@ class BaseStrategy(loadable.Loadable):
         """
         return {}
 
+    @property
+    def datasource_backend(self):
+        if not self._datasource_backend:
+            self._datasource_backend = ds_manager.DataSourceManager(
+                config=self.config,
+                osc=self.osc
+            ).get_backend(self.DATASOURCE_METRICS)
+        return self._datasource_backend
+
     @property
     def input_parameters(self):
         return self._input_parameters
@@ -253,13 +355,6 @@ class BaseStrategy(loadable.Loadable):
     def audit_scope(self, s):
         self._audit_scope = s
 
-    @property
-    def audit_scope_handler(self):
-        if not self._audit_scope_handler:
-            self._audit_scope_handler = default_scope.DefaultScope(
-                self.audit_scope, self.config)
-        return self._audit_scope_handler
-
     @property
     def name(self):
         return self._name
@@ -331,6 +426,8 @@ class UnclassifiedStrategy(BaseStrategy):
 @six.add_metaclass(abc.ABCMeta)
 class ServerConsolidationBaseStrategy(BaseStrategy):
 
+    REASON_FOR_DISABLE = 'watcher_disabled'
+
     @classmethod
     def get_goal_name(cls):
         return "server_consolidation"
@@ -366,3 +463,11 @@ class SavingEnergyBaseStrategy(BaseStrategy):
     @classmethod
     def get_goal_name(cls):
         return "saving_energy"
+
+
+@six.add_metaclass(abc.ABCMeta)
+class ZoneMigrationBaseStrategy(BaseStrategy):
+
+    @classmethod
+    def get_goal_name(cls):
+        return "hardware_maintenance"
