@@ -52,7 +52,6 @@ correctly on all compute nodes within the cluster.
 This strategy assumes it is possible to live migrate any VM from
 an active compute node to any other active compute node.
 """
-import datetime
 
 from oslo_config import cfg
 from oslo_log import log
@@ -60,8 +59,6 @@ import six
 
 from watcher._i18n import _
 from watcher.common import exception
-from watcher.datasource import ceilometer as ceil
-from watcher.datasource import gnocchi as gnoc
 from watcher.decision_engine.model import element
 from watcher.decision_engine.strategy.strategies import base
 
@@ -74,6 +71,9 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
     HOST_CPU_USAGE_METRIC_NAME = 'compute.node.cpu.percent'
     INSTANCE_CPU_USAGE_METRIC_NAME = 'cpu_util'
 
+    DATASOURCE_METRICS = ['instance_ram_allocated', 'instance_cpu_usage',
+                          'instance_ram_usage', 'instance_root_disk_size']
+
     METRIC_NAMES = dict(
         ceilometer=dict(
             cpu_util_metric='cpu_util',
@@ -115,26 +115,6 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
     def period(self):
         return self.input_parameters.get('period', 3600)
 
-    @property
-    def ceilometer(self):
-        if self._ceilometer is None:
-            self._ceilometer = ceil.CeilometerHelper(osc=self.osc)
-        return self._ceilometer
-
-    @ceilometer.setter
-    def ceilometer(self, ceilometer):
-        self._ceilometer = ceilometer
-
-    @property
-    def gnocchi(self):
-        if self._gnocchi is None:
-            self._gnocchi = gnoc.GnocchiHelper(osc=self.osc)
-        return self._gnocchi
-
-    @gnocchi.setter
-    def gnocchi(self, gnocchi):
-        self._gnocchi = gnocchi
-
     @property
     def granularity(self):
         return self.input_parameters.get('granularity', 300)
@@ -165,10 +145,18 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
             cfg.StrOpt(
                 "datasource",
                 help="Data source to use in order to query the needed metrics",
-                default="ceilometer",
+                default="gnocchi",
                 choices=["ceilometer", "gnocchi"])
         ]
 
+    def get_available_compute_nodes(self):
+        default_node_scope = [element.ServiceState.ENABLED.value,
+                              element.ServiceState.DISABLED.value]
+        return {uuid: cn for uuid, cn in
+                self.compute_model.get_all_compute_nodes().items()
+                if cn.state == element.ServiceState.ONLINE.value and
+                cn.status in default_node_scope}
+
     def get_instance_state_str(self, instance):
         """Get instance state in string format.
 
@@ -220,7 +208,8 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         :param node: node object
         :return: None
         """
-        params = {'state': element.ServiceState.DISABLED.value}
+        params = {'state': element.ServiceState.DISABLED.value,
+                  'disabled_reason': self.REASON_FOR_DISABLE}
         self.solution.add_action(
             action_type=self.CHANGE_NOVA_SERVICE_STATE,
             resource_id=node.uuid,
@@ -236,7 +225,8 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         :return: None
         """
         instance_state_str = self.get_instance_state_str(instance)
-        if instance_state_str != element.InstanceState.ACTIVE.value:
+        if instance_state_str not in (element.InstanceState.ACTIVE.value,
+                                      element.InstanceState.PAUSED.value):
             # Watcher currently only supports live VM migration and block live
             # VM migration which both requires migrated VM to be active.
             # When supported, the cold migration may be used as a fallback
@@ -273,7 +263,7 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
 
         :return: None
         """
-        for node in self.compute_model.get_all_compute_nodes().values():
+        for node in self.get_available_compute_nodes().values():
             if (len(self.compute_model.get_node_instances(node)) == 0 and
                     node.status !=
                     element.ServiceState.DISABLED.value):
@@ -302,57 +292,28 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         disk_alloc_metric = self.METRIC_NAMES[
             self.config.datasource]['disk_alloc_metric']
 
-        if self.config.datasource == "ceilometer":
-            instance_cpu_util = self.ceilometer.statistic_aggregation(
-                resource_id=instance.uuid, meter_name=cpu_util_metric,
-                period=self.period, aggregate='avg')
-            instance_ram_util = self.ceilometer.statistic_aggregation(
-                resource_id=instance.uuid, meter_name=ram_util_metric,
-                period=self.period, aggregate='avg')
-            if not instance_ram_util:
-                instance_ram_util = self.ceilometer.statistic_aggregation(
-                    resource_id=instance.uuid, meter_name=ram_alloc_metric,
-                    period=self.period, aggregate='avg')
-            instance_disk_util = self.ceilometer.statistic_aggregation(
-                resource_id=instance.uuid, meter_name=disk_alloc_metric,
-                period=self.period, aggregate='avg')
-        elif self.config.datasource == "gnocchi":
-            stop_time = datetime.datetime.utcnow()
-            start_time = stop_time - datetime.timedelta(
-                seconds=int(self.period))
-            instance_cpu_util = self.gnocchi.statistic_aggregation(
+        instance_cpu_util = self.datasource_backend.statistic_aggregation(
+            resource_id=instance.uuid,
+            meter_name=cpu_util_metric,
+            period=self.period,
+            granularity=self.granularity)
+        instance_ram_util = self.datasource_backend.statistic_aggregation(
+            resource_id=instance.uuid,
+            meter_name=ram_util_metric,
+            period=self.period,
+            granularity=self.granularity)
+        if not instance_ram_util:
+            instance_ram_util = self.datasource_backend.statistic_aggregation(
                 resource_id=instance.uuid,
-                metric=cpu_util_metric,
-                granularity=self.granularity,
-                start_time=start_time,
-                stop_time=stop_time,
-                aggregation='mean'
-            )
-            instance_ram_util = self.gnocchi.statistic_aggregation(
-                resource_id=instance.uuid,
-                metric=ram_util_metric,
-                granularity=self.granularity,
-                start_time=start_time,
-                stop_time=stop_time,
-                aggregation='mean'
-            )
-            if not instance_ram_util:
-                instance_ram_util = self.gnocchi.statistic_aggregation(
-                    resource_id=instance.uuid,
-                    metric=ram_alloc_metric,
-                    granularity=self.granularity,
-                    start_time=start_time,
-                    stop_time=stop_time,
-                    aggregation='mean'
-                )
-            instance_disk_util = self.gnocchi.statistic_aggregation(
-                resource_id=instance.uuid,
-                metric=disk_alloc_metric,
-                granularity=self.granularity,
-                start_time=start_time,
-                stop_time=stop_time,
-                aggregation='mean'
-            )
+                meter_name=ram_alloc_metric,
+                period=self.period,
+                granularity=self.granularity)
+        instance_disk_util = self.datasource_backend.statistic_aggregation(
+            resource_id=instance.uuid,
+            meter_name=disk_alloc_metric,
+            period=self.period,
+            granularity=self.granularity)
+
         if instance_cpu_util:
             total_cpu_utilization = (
                 instance.vcpus * (instance_cpu_util / 100.0))
@@ -422,7 +383,7 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         RCU is an average of relative utilizations (rhu) of active nodes.
         :return: {'cpu': <0,1>, 'ram': <0,1>, 'disk': <0,1>}
         """
-        nodes = self.compute_model.get_all_compute_nodes().values()
+        nodes = self.get_available_compute_nodes().values()
         rcu = {}
         counters = {}
         for node in nodes:
@@ -534,7 +495,7 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         :param cc: dictionary containing resource capacity coefficients
         """
         sorted_nodes = sorted(
-            self.compute_model.get_all_compute_nodes().values(),
+            self.get_available_compute_nodes().values(),
             key=lambda x: self.get_node_utilization(x)['cpu'])
         for node in reversed(sorted_nodes):
             if self.is_overloaded(node, cc):
@@ -567,7 +528,7 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         :param cc: dictionary containing resource capacity coefficients
         """
         sorted_nodes = sorted(
-            self.compute_model.get_all_compute_nodes().values(),
+            self.get_available_compute_nodes().values(),
             key=lambda x: self.get_node_utilization(x)['cpu'])
         asc = 0
         for node in sorted_nodes:
@@ -630,7 +591,7 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         rcu_after = self.get_relative_cluster_utilization()
         info = {
             "compute_nodes_count": len(
-                self.compute_model.get_all_compute_nodes()),
+                self.get_available_compute_nodes()),
             'number_of_migrations': self.number_of_migrations,
             'number_of_released_nodes':
                 self.number_of_released_nodes,
@@ -643,7 +604,7 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
     def post_execute(self):
         self.solution.set_efficacy_indicators(
             compute_nodes_count=len(
-                self.compute_model.get_all_compute_nodes()),
+                self.get_available_compute_nodes()),
             released_compute_nodes_count=self.number_of_released_nodes,
             instance_migrations_count=self.number_of_migrations,
         )
