@@ -169,7 +169,8 @@ class TestListAction(api_base.FunctionalTest):
             action_list.append(action.uuid)
 
         audit2 = obj_utils.create_test_audit(
-            self.context, id=2, uuid=utils.generate_uuid())
+            self.context, id=2, uuid=utils.generate_uuid(),
+            name='My Audit {0}'.format(2))
         action_plan_2 = obj_utils.create_test_action_plan(
             self.context,
             uuid=utils.generate_uuid(),
@@ -295,6 +296,8 @@ class TestListAction(api_base.FunctionalTest):
                 uuid=utils.generate_uuid())
             ap2_action_list.append(action)
 
+        action_plan1.state = objects.action_plan.State.CANCELLED
+        action_plan1.save()
         self.delete('/action_plans/%s' % action_plan1.uuid)
 
         response = self.get_json('/actions')
