@@ -128,12 +128,12 @@ class TestListActionPlan(api_base.FunctionalTest):
 
     def test_many_with_soft_deleted_audit_uuid(self):
         action_plan_list = []
-        audit1 = obj_utils.create_test_audit(self.context,
-                                             id=2,
-                                             uuid=utils.generate_uuid())
-        audit2 = obj_utils.create_test_audit(self.context,
-                                             id=3,
-                                             uuid=utils.generate_uuid())
+        audit1 = obj_utils.create_test_audit(
+            self.context, id=2,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(2))
+        audit2 = obj_utils.create_test_audit(
+            self.context, id=3,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(3))
 
         for id_ in range(0, 2):
             action_plan = obj_utils.create_test_action_plan(
@@ -147,6 +147,11 @@ class TestListActionPlan(api_base.FunctionalTest):
                 audit_id=audit2.id)
             action_plan_list.append(action_plan.uuid)
 
+        new_state = objects.audit.State.CANCELLED
+        self.patch_json(
+            '/audits/%s' % audit1.uuid,
+            [{'path': '/state', 'value': new_state,
+             'op': 'replace'}])
         self.delete('/audits/%s' % audit1.uuid)
 
         response = self.get_json('/action_plans')
@@ -163,9 +168,9 @@ class TestListActionPlan(api_base.FunctionalTest):
 
     def test_many_with_audit_uuid(self):
         action_plan_list = []
-        audit = obj_utils.create_test_audit(self.context,
-                                            id=2,
-                                            uuid=utils.generate_uuid())
+        audit = obj_utils.create_test_audit(
+            self.context, id=2,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(2))
         for id_ in range(2, 5):
             action_plan = obj_utils.create_test_action_plan(
                 self.context, id=id_, uuid=utils.generate_uuid(),
@@ -178,18 +183,18 @@ class TestListActionPlan(api_base.FunctionalTest):
 
     def test_many_with_audit_uuid_filter(self):
         action_plan_list1 = []
-        audit1 = obj_utils.create_test_audit(self.context,
-                                             id=2,
-                                             uuid=utils.generate_uuid())
+        audit1 = obj_utils.create_test_audit(
+            self.context, id=2,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(2))
         for id_ in range(2, 5):
             action_plan = obj_utils.create_test_action_plan(
                 self.context, id=id_, uuid=utils.generate_uuid(),
                 audit_id=audit1.id)
             action_plan_list1.append(action_plan.uuid)
 
-        audit2 = obj_utils.create_test_audit(self.context,
-                                             id=3,
-                                             uuid=utils.generate_uuid())
+        audit2 = obj_utils.create_test_audit(
+            self.context, id=3,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(3))
         action_plan_list2 = []
         for id_ in [5, 6, 7]:
             action_plan = obj_utils.create_test_action_plan(
@@ -237,9 +242,9 @@ class TestListActionPlan(api_base.FunctionalTest):
     def test_many_with_sort_key_audit_uuid(self):
         audit_list = []
         for id_ in range(2, 5):
-            audit = obj_utils.create_test_audit(self.context,
-                                                id=id_,
-                                                uuid=utils.generate_uuid())
+            audit = obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
             obj_utils.create_test_action_plan(
                 self.context, id=id_, uuid=utils.generate_uuid(),
                 audit_id=audit.id)
@@ -304,6 +309,13 @@ class TestDelete(api_base.FunctionalTest):
         action_plan.destroy()
 
     def test_delete_action_plan_without_action(self):
+        response = self.delete('/action_plans/%s' % self.action_plan.uuid,
+                               expect_errors=True)
+        self.assertEqual(400, response.status_int)
+        self.assertEqual('application/json', response.content_type)
+        self.assertTrue(response.json['error_message'])
+        self.action_plan.state = objects.action_plan.State.SUCCEEDED
+        self.action_plan.save()
         self.delete('/action_plans/%s' % self.action_plan.uuid)
         response = self.get_json('/action_plans/%s' % self.action_plan.uuid,
                                  expect_errors=True)
@@ -315,6 +327,8 @@ class TestDelete(api_base.FunctionalTest):
         action = obj_utils.create_test_action(
             self.context, id=1)
 
+        self.action_plan.state = objects.action_plan.State.SUCCEEDED
+        self.action_plan.save()
         self.delete('/action_plans/%s' % self.action_plan.uuid)
         ap_response = self.get_json('/action_plans/%s' % self.action_plan.uuid,
                                     expect_errors=True)
