@@ -154,8 +154,9 @@ class TestListAudit(api_base.FunctionalTest):
     def test_many(self):
         audit_list = []
         for id_ in range(5):
-            audit = obj_utils.create_test_audit(self.context, id=id_,
-                                                uuid=utils.generate_uuid())
+            audit = obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
             audit_list.append(audit.uuid)
         response = self.get_json('/audits')
         self.assertEqual(len(audit_list), len(response['audits']))
@@ -165,12 +166,14 @@ class TestListAudit(api_base.FunctionalTest):
     def test_many_without_soft_deleted(self):
         audit_list = []
         for id_ in [1, 2, 3]:
-            audit = obj_utils.create_test_audit(self.context, id=id_,
-                                                uuid=utils.generate_uuid())
+            audit = obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
             audit_list.append(audit.uuid)
         for id_ in [4, 5]:
-            audit = obj_utils.create_test_audit(self.context, id=id_,
-                                                uuid=utils.generate_uuid())
+            audit = obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
             audit.soft_delete()
         response = self.get_json('/audits')
         self.assertEqual(3, len(response['audits']))
@@ -180,12 +183,14 @@ class TestListAudit(api_base.FunctionalTest):
     def test_many_with_soft_deleted(self):
         audit_list = []
         for id_ in [1, 2, 3]:
-            audit = obj_utils.create_test_audit(self.context, id=id_,
-                                                uuid=utils.generate_uuid())
+            audit = obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
             audit_list.append(audit.uuid)
         for id_ in [4, 5]:
-            audit = obj_utils.create_test_audit(self.context, id=id_,
-                                                uuid=utils.generate_uuid())
+            audit = obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
             audit.soft_delete()
             audit_list.append(audit.uuid)
         response = self.get_json('/audits',
@@ -203,7 +208,7 @@ class TestListAudit(api_base.FunctionalTest):
                 uuid=utils.generate_uuid())
             obj_utils.create_test_audit(
                 self.context, id=id_, uuid=utils.generate_uuid(),
-                goal_id=goal.id)
+                goal_id=goal.id, name='My Audit {0}'.format(id_))
             goal_list.append(goal.uuid)
 
         response = self.get_json('/audits/?sort_key=goal_uuid')
@@ -214,7 +219,9 @@ class TestListAudit(api_base.FunctionalTest):
 
     def test_links(self):
         uuid = utils.generate_uuid()
-        obj_utils.create_test_audit(self.context, id=1, uuid=uuid)
+        obj_utils.create_test_audit(
+            self.context, id=1, uuid=uuid,
+            name='My Audit {0}'.format(1))
         response = self.get_json('/audits/%s' % uuid)
         self.assertIn('links', response.keys())
         self.assertEqual(2, len(response['links']))
@@ -225,8 +232,9 @@ class TestListAudit(api_base.FunctionalTest):
 
     def test_collection_links(self):
         for id_ in range(5):
-            obj_utils.create_test_audit(self.context, id=id_,
-                                        uuid=utils.generate_uuid())
+            obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
         response = self.get_json('/audits/?limit=3')
         self.assertEqual(3, len(response['audits']))
 
@@ -236,8 +244,9 @@ class TestListAudit(api_base.FunctionalTest):
     def test_collection_links_default_limit(self):
         cfg.CONF.set_override('max_limit', 3, 'api')
         for id_ in range(5):
-            obj_utils.create_test_audit(self.context, id=id_,
-                                        uuid=utils.generate_uuid())
+            obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
         response = self.get_json('/audits')
         self.assertEqual(3, len(response['audits']))
 
@@ -712,7 +721,7 @@ class TestPost(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(400, response.status_int)
         expected_error_msg = ('Specify parameters but no predefined '
-                              'strategy for audit template, or no '
+                              'strategy for audit, or no '
                               'parameter spec in predefined strategy')
         self.assertTrue(response.json['error_message'])
         self.assertIn(expected_error_msg, response.json['error_message'])
@@ -734,7 +743,7 @@ class TestPost(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(400, response.status_int)
         expected_error_msg = ('Specify parameters but no predefined '
-                              'strategy for audit template, or no '
+                              'strategy for audit, or no '
                               'parameter spec in predefined strategy')
         self.assertTrue(response.json['error_message'])
         self.assertIn(expected_error_msg, response.json['error_message'])
@@ -797,6 +806,35 @@ class TestPost(api_base.FunctionalTest):
             strategy_id=strategy['id'], uuid=template_uuid, name=template_name)
         return audit_template
 
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    @mock.patch('oslo_utils.timeutils.utcnow')
+    def test_create_audit_with_name(self, mock_utcnow, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+        test_time = datetime.datetime(2000, 1, 1, 0, 0)
+        mock_utcnow.return_value = test_time
+
+        audit_dict = post_get_test_audit()
+        normal_name = 'this audit name is just for test'
+        # long_name length exceeds 63 characters
+        long_name = normal_name+audit_dict['uuid']
+        del audit_dict['uuid']
+        del audit_dict['state']
+        del audit_dict['interval']
+        del audit_dict['scope']
+        del audit_dict['next_run_time']
+
+        audit_dict['name'] = normal_name
+        response = self.post_json('/audits', audit_dict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertEqual(normal_name, response.json['name'])
+
+        audit_dict['name'] = long_name
+        response = self.post_json('/audits', audit_dict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertNotEqual(long_name, response.json['name'])
+
 
 class TestDelete(api_base.FunctionalTest):
 
@@ -819,6 +857,23 @@ class TestDelete(api_base.FunctionalTest):
     def test_delete_audit(self, mock_utcnow):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
+
+        new_state = objects.audit.State.ONGOING
+        self.patch_json(
+            '/audits/%s' % self.audit.uuid,
+            [{'path': '/state', 'value': new_state,
+             'op': 'replace'}])
+        response = self.delete('/audits/%s' % self.audit.uuid,
+                               expect_errors=True)
+        self.assertEqual(400, response.status_int)
+        self.assertEqual('application/json', response.content_type)
+        self.assertTrue(response.json['error_message'])
+
+        new_state = objects.audit.State.CANCELLED
+        self.patch_json(
+            '/audits/%s' % self.audit.uuid,
+            [{'path': '/state', 'value': new_state,
+             'op': 'replace'}])
         self.delete('/audits/%s' % self.audit.uuid)
         response = self.get_json('/audits/%s' % self.audit.uuid,
                                  expect_errors=True)
@@ -829,8 +884,10 @@ class TestDelete(api_base.FunctionalTest):
         self.context.show_deleted = True
         audit = objects.Audit.get_by_uuid(self.context, self.audit.uuid)
 
-        return_deleted_at = timeutils.strtime(audit['deleted_at'])
-        self.assertEqual(timeutils.strtime(test_time), return_deleted_at)
+        return_deleted_at = \
+            audit['deleted_at'].strftime('%Y-%m-%dT%H:%M:%S.%f')
+        self.assertEqual(test_time.strftime('%Y-%m-%dT%H:%M:%S.%f'),
+                         return_deleted_at)
         self.assertEqual(objects.audit.State.DELETED, audit['state'])
 
     def test_delete_audit_not_found(self):
