@@ -83,6 +83,7 @@ def get_test_audit(**kwargs):
     audit_data = {
         'id': kwargs.get('id', 1),
         'uuid': kwargs.get('uuid', '10a47dd1-4874-4298-91cf-eff046dbdb8d'),
+        'name': kwargs.get('name', 'My Audit'),
         'audit_type': kwargs.get('audit_type', 'ONESHOT'),
         'state': kwargs.get('state', objects.audit.State.PENDING),
         'created_at': kwargs.get('created_at'),
@@ -166,7 +167,7 @@ def get_test_action_plan(**kwargs):
         'state': kwargs.get('state', objects.action_plan.State.ONGOING),
         'audit_id': kwargs.get('audit_id', 1),
         'strategy_id': kwargs.get('strategy_id', 1),
-        'global_efficacy': kwargs.get('global_efficacy', {}),
+        'global_efficacy': kwargs.get('global_efficacy', []),
         'created_at': kwargs.get('created_at'),
         'updated_at': kwargs.get('updated_at'),
         'deleted_at': kwargs.get('deleted_at'),
